### Kubelka et al.: Global pattern of nest predation is disrupted by climate change in shorebirds.

### Modelling is presented first and then all figures separately (both parts are ordered sequentially as they appear in the manuscript).

### First part of script was prepared by R.F., then V.K. did the modelling.



rm( list = ls() )

library( ape )
library( coxme )
library( phytools )
library(ggplot2)
library(mgcv)

# -----------------------------------------------
# - Simple function for calculating distances ---
# -----------------------------------------------
geodetic <- function(l1, t1, l2, t2) {
  
  l1 <- l1 / 360.0 * 2.0 * pi
  l2 <- l2 / 360.0 * 2.0 * pi
  t1 <- t1 / 360.0 * 2.0 * pi
  t2 <- t2 / 360.0 * 2.0 * pi
  
  dist <- 6371.0 * acos( sin(t1) * sin(t2) + cos(t1) * cos(t2) * cos(l2 - l1) )
  
  return(dist)
  
}

# -----------------------------------------------
# ------- Generates a distance matrix -------
# -----------------------------------------------
dist.mat <- function(lat, lon, rwnms) {
  n <- length( lat )
  mat <- matrix(0, n, n )
  
  for(i in 1:n) {
    for( j in 1:n) {
      mat[i, j] <- geodetic( lon[i], lat[i], lon[j], lat[j] )
      if( is.na( mat[i,j]) == TRUE ) mat[i,j] <- 0    # Nasty
    }
  }
  
  mdist <- geodetic(-90,-90, 90,90)
  mat <- mdist - mat
  diag(mat) <- mdist
  mat <- mat / mdist
  rownames(mat) <- rwnms
  return(mat)
  
}

bind.tip<-function(tree,tip.label,edge.length=NULL,where=NULL){
  if(is.null(where)) where<-length(tree$tip)+1
  tip<-list(edge=matrix(c(2,1),1,2),
            tip.label=tip.label,
            edge.length=edge.length,
            Nnode=1)
  class(tip)<-"phylo"
  obj<-bind.tree(tree,tip,where=where)
  return(obj)
}


# ------- Analyse the population-level data -------------

# Load up the data and trees
trees <- read.tree( "trees2.phy" )
data <- read.csv( "DATApopulations.csv", h = T, sep = ";")
tree <- trees[[42]]  # just choose one to start with
plotTree(tree, node.numbers = TRUE, fsize = 0.5)


# Add in the missing species
# From email of 12/12/16: 
# " There are all (109) except of two species:
#   Charadrius nivosus (sister taxon of Charadrius alexandrius)
#   Gallinago delicata (sister taxon of Gallinago gallinago) "



# How to add in a tip:

idx <- which( tree$tip == "Charadrius_alexandrinus")
np <- nodepath(tree)[[idx]]
to <- np[ length( np ) - 1] 
ed <- which( tree$edge[,2] == idx)

tree1 <- bind.tip( tree, "Charadrius_nivosus", edge.length = tree$edge.length[ed], where = to )
plotTree(tree1, node.numbers = TRUE, fsize = 0.5)


addInTip <- function( phylo, where, newname) {
  idx <- which( phylo$tip == where )
  np <- nodepath( phylo)[[idx]]
  to <- np[ length(np) -1 ]
  ed <- which( tree$edge[,2] == idx )
  newphylo <- bind.tip( phylo, newname, edge.length = phylo$edge.length[ed], where = to )
  return( newphylo)
}


tree2 <- addInTip( tree1,"Gallinago_gallinago", "Gallinago_delicata" )
plotTree(tree2, node.numbers = TRUE, fsize = 0.5)



# Now do all trees 
trees1 <- lapply( trees, function( t ) addInTip( t , "Charadrius_alexandrinus","Charadrius_nivosus" )  )
trees2 <- lapply( trees1, function( t ) addInTip( t , "Gallinago_gallinago", "Gallinago_delicata") ) 



# Create phylogenetic geographic and PI matrices
phyloMat <- vcv.phylo( tree2 )
phyloMat <- phyloMat / max( phyloMat )
distanceMatrix <- dist.mat( data$Latitude, data$Longitude, data$species ) 
diag( distanceMatrix ) <- diag(distanceMatrix) + 0.01
distanceMatrix <- distanceMatrix / 1.01

idxMat <- apply( phyloMat, 1:2, function(i) as.numeric( i > 0) )


I0 <- diag(1, dim(data)[1] )
rownames(I0) <- colnames(I0) <- data$species 
 I <- diag(1 / data$N_nests )
 
I <- I / max(I)
rownames(I) <- colnames(I) <- data$species 


# Form a matrix representing species identity
m <- as.matrix( model.matrix( ~ species-1, data = data) )
S <- crossprod(t(m), t(m) )
rownames(S) <- colnames(S) <- data$species 


# Create a latitude variable

data$NS <- data$Latitude > 0




### -----------------------------------------------
### - Fig. 2A; Table S2. ---- Daily nest predation in respect to time at different latitudes  (five latitudinal areas)
### -----------------------------------------------


### All data first

data <- read.csv( "DATApopulations.csv", h = T, sep=";")

#  Create phylogenetic geographic and PI matrices
phyloMat <- vcv.phylo( tree2 )
phyloMat <- phyloMat / max( phyloMat )
distanceMatrix <- dist.mat( data$Latitude, data$Longitude, data$species ) 
diag( distanceMatrix ) <- diag(distanceMatrix) + 0.01
distanceMatrix <- distanceMatrix / 1.01

idxMat <- apply( phyloMat, 1:2, function(i) as.numeric( i > 0) )


I0 <- diag(1, dim(data)[1] )
rownames(I0) <- colnames(I0) <- data$species 
 I <- diag(1 / data$N_nests )
 
I <- I / max(I)
rownames(I) <- colnames(I) <- data$species 


# Form a matrix representing species identity
m <- as.matrix( model.matrix( ~ species-1, data = data) )
S <- crossprod(t(m), t(m) )
rownames(S) <- colnames(S) <- data$species 

# Create a latitude variable

data$NS <- data$Latitude > 0


Model_1 <- lmekin( log(DPR) ~ (1|species ) + mean_year + log( N_nests) , varlist = list( I, phyloMat , distanceMatrix ), data = data )
Model_1

par(mfrow = c(1, 2))
plot(density(resid(Model_1)))
qqnorm(resid(Model_1))
qqline(resid(Model_1))
par(mfrow = c(1, 1))
## - check for data normality -> ok



### South_temperate area (-62-30 latitude)

data <- read.csv( "South_temperate.csv", sep=";")

#  Create phylogenetic geographic and PI matrices
phyloMat <- vcv.phylo( tree2 )
phyloMat <- phyloMat / max( phyloMat )
distanceMatrix <- dist.mat( data$Latitude, data$Longitude, data$species ) 
diag( distanceMatrix ) <- diag(distanceMatrix) + 0.01
distanceMatrix <- distanceMatrix / 1.01

idxMat <- apply( phyloMat, 1:2, function(i) as.numeric( i > 0) )


I0 <- diag(1, dim(data)[1] )
rownames(I0) <- colnames(I0) <- data$species 
 I <- diag(1 / data$N_nests )
 
I <- I / max(I)
rownames(I) <- colnames(I) <- data$species 


# Form a matrix representing species identity
m <- as.matrix( model.matrix( ~ species-1, data = data) )
S <- crossprod(t(m), t(m) )
rownames(S) <- colnames(S) <- data$species 

# Create a latitude variable

data$NS <- data$Latitude > 0


Model_2 <- lmekin( log(DPR) ~ (1|species ) + mean_year + log( N_nests) , varlist = list( I, phyloMat , distanceMatrix ), data = data )
Model_2

par(mfrow = c(1, 2))
plot(density(resid(Model_2)))
qqnorm(resid(Model_2))
qqline(resid(Model_2))
par(mfrow = c(1, 1))
## - check for data normality -> ok given sample size



### South_tropics area (-30-0 latitude)

data <- read.csv( "South_tropics.csv", sep=";")

#  Create phylogenetic geographic and PI matrices
phyloMat <- vcv.phylo( tree2 )
phyloMat <- phyloMat / max( phyloMat )
distanceMatrix <- dist.mat( data$Latitude, data$Longitude, data$species ) 
diag( distanceMatrix ) <- diag(distanceMatrix) + 0.01
distanceMatrix <- distanceMatrix / 1.01

idxMat <- apply( phyloMat, 1:2, function(i) as.numeric( i > 0) )


I0 <- diag(1, dim(data)[1] )
rownames(I0) <- colnames(I0) <- data$species 
 I <- diag(1 / data$N_nests )
 
I <- I / max(I)
rownames(I) <- colnames(I) <- data$species 


# Form a matrix representing species identity
m <- as.matrix( model.matrix( ~ species-1, data = data) )
S <- crossprod(t(m), t(m) )
rownames(S) <- colnames(S) <- data$species 

# Create a latitude variable

data$NS <- data$Latitude > 0


Model_3 <- lmekin( log(DPR) ~ (1|species ) + mean_year + log( N_nests) , varlist = list( I, phyloMat , distanceMatrix ), data = data )
Model_3

par(mfrow = c(1, 2))
plot(density(resid(Model_3)))
qqnorm(resid(Model_3))
qqline(resid(Model_3))
par(mfrow = c(1, 1))
## - check for data normality -> ok



### North_tropics area (0-30 latitude)

data <- read.csv( "North_tropics.csv", sep=";")

#  Create phylogenetic geographic and PI matrices
phyloMat <- vcv.phylo( tree2 )
phyloMat <- phyloMat / max( phyloMat )
distanceMatrix <- dist.mat( data$Latitude, data$Longitude, data$species ) 
diag( distanceMatrix ) <- diag(distanceMatrix) + 0.01
distanceMatrix <- distanceMatrix / 1.01

idxMat <- apply( phyloMat, 1:2, function(i) as.numeric( i > 0) )


I0 <- diag(1, dim(data)[1] )
rownames(I0) <- colnames(I0) <- data$species 
 I <- diag(1 / data$N_nests )
 
I <- I / max(I)
rownames(I) <- colnames(I) <- data$species 


# Form a matrix representing species identity
m <- as.matrix( model.matrix( ~ species-1, data = data) )
S <- crossprod(t(m), t(m) )
rownames(S) <- colnames(S) <- data$species 

# Create a latitude variable

data$NS <- data$Latitude > 0


Model_4 <- lmekin( log(DPR) ~ (1|species ) + mean_year + log( N_nests) , varlist = list( I, phyloMat , distanceMatrix ), data = data )
Model_4

par(mfrow = c(1, 2))
plot(density(resid(Model_4)))
qqnorm(resid(Model_4))
qqline(resid(Model_4))
par(mfrow = c(1, 1))
## - check for data normality -> ok


### North_temperate area (0-30 latitude)

data <- read.csv( "North_temperate.csv", sep=";")

#  Create phylogenetic geographic and PI matrices
phyloMat <- vcv.phylo( tree2 )
phyloMat <- phyloMat / max( phyloMat )
distanceMatrix <- dist.mat( data$Latitude, data$Longitude, data$species ) 
diag( distanceMatrix ) <- diag(distanceMatrix) + 0.01
distanceMatrix <- distanceMatrix / 1.01

idxMat <- apply( phyloMat, 1:2, function(i) as.numeric( i > 0) )


I0 <- diag(1, dim(data)[1] )
rownames(I0) <- colnames(I0) <- data$species 
 I <- diag(1 / data$N_nests )
 
I <- I / max(I)
rownames(I) <- colnames(I) <- data$species 


# Form a matrix representing species identity
m <- as.matrix( model.matrix( ~ species-1, data = data) )
S <- crossprod(t(m), t(m) )
rownames(S) <- colnames(S) <- data$species 

# Create a latitude variable

data$NS <- data$Latitude > 0


Model_5 <- lmekin( log(DPR) ~ (1|species ) + mean_year + log( N_nests) , varlist = list( I, phyloMat , distanceMatrix ), data = data )
Model_5

par(mfrow = c(1, 2))
plot(density(resid(Model_5)))
qqnorm(resid(Model_5))
qqline(resid(Model_5))
par(mfrow = c(1, 1))
## - check for data normality -> ok



### Arctic (60-78 latitude)

data <- read.csv( "Arctic.csv", sep=";")

# Create phylogenetic geographic and PI matrices
phyloMat <- vcv.phylo( tree2 )
phyloMat <- phyloMat / max( phyloMat )
distanceMatrix <- dist.mat( data$Latitude, data$Longitude, data$species ) 

diag( distanceMatrix ) <- diag(distanceMatrix) + 0.01
distanceMatrix <- distanceMatrix / 1.01 
idxMat <- apply( phyloMat, 1:2, function(i) as.numeric( i > 0) )
I0 <- diag(1, dim(data)[1] )
rownames(I0) <- colnames(I0) <- data$species 
 I <- diag(1 / data$N_nests )
 
I <- I / max(I)
rownames(I) <- colnames(I) <- data$species 

# Form a matrix representing species identity
m <- as.matrix( model.matrix( ~ species-1, data = data) )
S <- crossprod(t(m), t(m) )
rownames(S) <- colnames(S) <- data$species 


Model_6 <- lmekin( log(DPR) ~ (1|species) + mean_year + log( N_nests), varlist = list( I, phyloMat, distanceMatrix), data = data )
Model_6

par(mfrow = c(1, 2))
plot(density(resid(Model_6)))
qqnorm(resid(Model_6))
qqline(resid(Model_6))
par(mfrow = c(1, 1))
## - check for data normality -> ok




### -----------------------------------------------
### - Fig. 2B; Table S2. ---- Total nest predation in respect to time at different latitudes (five latitudinal areas)
### -----------------------------------------------

### All data first

data <- read.csv( "DATApopulations.csv", sep=";")

#  Create phylogenetic geographic and PI matrices
phyloMat <- vcv.phylo( tree2 )
phyloMat <- phyloMat / max( phyloMat )
distanceMatrix <- dist.mat( data$Latitude, data$Longitude, data$species ) 
diag( distanceMatrix ) <- diag(distanceMatrix) + 0.01
distanceMatrix <- distanceMatrix / 1.01

idxMat <- apply( phyloMat, 1:2, function(i) as.numeric( i > 0) )


I0 <- diag(1, dim(data)[1] )
rownames(I0) <- colnames(I0) <- data$species 
 I <- diag(1 / data$N_nests )
 
I <- I / max(I)
rownames(I) <- colnames(I) <- data$species 


# Form a matrix representing species identity
m <- as.matrix( model.matrix( ~ species-1, data = data) )
S <- crossprod(t(m), t(m) )
rownames(S) <- colnames(S) <- data$species 

# Create a latitude variable

data$NS <- data$Latitude > 0


Model_7 <- lmekin( TPR ~ (1|species ) + mean_year + log( N_nests) , varlist = list( I, phyloMat , distanceMatrix ), data = data )
Model_7

par(mfrow = c(1, 2))
plot(density(resid(Model_7)))
qqnorm(resid(Model_7))
qqline(resid(Model_7))
par(mfrow = c(1, 1))
## - check for data normality -> ok



### South_temperate area (-62-30 latitude)

data <- read.csv( "South_temperate.csv", sep=";")

#  Create phylogenetic geographic and PI matrices
phyloMat <- vcv.phylo( tree2 )
phyloMat <- phyloMat / max( phyloMat )
distanceMatrix <- dist.mat( data$Latitude, data$Longitude, data$species ) 
diag( distanceMatrix ) <- diag(distanceMatrix) + 0.01
distanceMatrix <- distanceMatrix / 1.01

idxMat <- apply( phyloMat, 1:2, function(i) as.numeric( i > 0) )


I0 <- diag(1, dim(data)[1] )
rownames(I0) <- colnames(I0) <- data$species 
 I <- diag(1 / data$N_nests )
 
I <- I / max(I)
rownames(I) <- colnames(I) <- data$species 


# Form a matrix representing species identity
m <- as.matrix( model.matrix( ~ species-1, data = data) )
S <- crossprod(t(m), t(m) )
rownames(S) <- colnames(S) <- data$species 

# Create a latitude variable

data$NS <- data$Latitude > 0


Model_8 <- lmekin( TPR ~ (1|species ) + mean_year + log( N_nests) , varlist = list( I, phyloMat , distanceMatrix ), data = data )
Model_8

par(mfrow = c(1, 2))
plot(density(resid(Model_8)))
qqnorm(resid(Model_8))
qqline(resid(Model_8))
par(mfrow = c(1, 1))
## - check for data normality -> ok given sample size 



### South_tropics area (-30-0 latitude)

data <- read.csv( "South_tropics.csv", sep=";")

#  Create phylogenetic geographic and PI matrices
phyloMat <- vcv.phylo( tree2 )
phyloMat <- phyloMat / max( phyloMat )
distanceMatrix <- dist.mat( data$Latitude, data$Longitude, data$species ) 
diag( distanceMatrix ) <- diag(distanceMatrix) + 0.01
distanceMatrix <- distanceMatrix / 1.01

idxMat <- apply( phyloMat, 1:2, function(i) as.numeric( i > 0) )


I0 <- diag(1, dim(data)[1] )
rownames(I0) <- colnames(I0) <- data$species 
 I <- diag(1 / data$N_nests )
 
I <- I / max(I)
rownames(I) <- colnames(I) <- data$species 


# Form a matrix representing species identity
m <- as.matrix( model.matrix( ~ species-1, data = data) )
S <- crossprod(t(m), t(m) )
rownames(S) <- colnames(S) <- data$species 

# Create a latitude variable

data$NS <- data$Latitude > 0


Model_9 <- lmekin( TPR ~ (1|species ) + mean_year + log( N_nests) , varlist = list( I, phyloMat , distanceMatrix ), data = data )
Model_9

par(mfrow = c(1, 2))
plot(density(resid(Model_9)))
qqnorm(resid(Model_9))
qqline(resid(Model_9))
par(mfrow = c(1, 1))
## - check for data normality -> ok



### North_tropics area (0-30 latitude)

data <- read.csv( "North_tropics.csv", sep=";")

#  Create phylogenetic geographic and PI matrices
phyloMat <- vcv.phylo( tree2 )
phyloMat <- phyloMat / max( phyloMat )
distanceMatrix <- dist.mat( data$Latitude, data$Longitude, data$species ) 
diag( distanceMatrix ) <- diag(distanceMatrix) + 0.01
distanceMatrix <- distanceMatrix / 1.01

idxMat <- apply( phyloMat, 1:2, function(i) as.numeric( i > 0) )


I0 <- diag(1, dim(data)[1] )
rownames(I0) <- colnames(I0) <- data$species 
 I <- diag(1 / data$N_nests )
 
I <- I / max(I)
rownames(I) <- colnames(I) <- data$species 


# Form a matrix representing species identity
m <- as.matrix( model.matrix( ~ species-1, data = data) )
S <- crossprod(t(m), t(m) )
rownames(S) <- colnames(S) <- data$species 

# Create a latitude variable

data$NS <- data$Latitude > 0


Model_10 <- lmekin( TPR ~ (1|species ) + mean_year + log( N_nests) , varlist = list( I, phyloMat , distanceMatrix ), data = data )
Model_10

par(mfrow = c(1, 2))
plot(density(resid(Model_10)))
qqnorm(resid(Model_10))
qqline(resid(Model_10))
par(mfrow = c(1, 1))
## - check for data normality -> ok


### North_temperate area (0-30 latitude)

data <- read.csv( "North_temperate.csv", sep=";")

#  Create phylogenetic geographic and PI matrices
phyloMat <- vcv.phylo( tree2 )
phyloMat <- phyloMat / max( phyloMat )
distanceMatrix <- dist.mat( data$Latitude, data$Longitude, data$species ) 
diag( distanceMatrix ) <- diag(distanceMatrix) + 0.01
distanceMatrix <- distanceMatrix / 1.01

idxMat <- apply( phyloMat, 1:2, function(i) as.numeric( i > 0) )


I0 <- diag(1, dim(data)[1] )
rownames(I0) <- colnames(I0) <- data$species 
 I <- diag(1 / data$N_nests )
 
I <- I / max(I)
rownames(I) <- colnames(I) <- data$species 


# Form a matrix representing species identity
m <- as.matrix( model.matrix( ~ species-1, data = data) )
S <- crossprod(t(m), t(m) )
rownames(S) <- colnames(S) <- data$species 

# Create a latitude variable

data$NS <- data$Latitude > 0


Model_11 <- lmekin( TPR ~ (1|species ) + mean_year + log( N_nests) , varlist = list( I, phyloMat , distanceMatrix ), data = data )
Model_11

par(mfrow = c(1, 2))
plot(density(resid(Model_11)))
qqnorm(resid(Model_11))
qqline(resid(Model_11))
par(mfrow = c(1, 1))
## - check for data normality -> ok



### Arctic (60-78 latitude)

data <- read.csv( "Arctic.csv", sep=";")

# Create phylogenetic geographic and PI matrices
phyloMat <- vcv.phylo( tree2 )
phyloMat <- phyloMat / max( phyloMat )
distanceMatrix <- dist.mat( data$Latitude, data$Longitude, data$species ) 

diag( distanceMatrix ) <- diag(distanceMatrix) + 0.01
distanceMatrix <- distanceMatrix / 1.01 
idxMat <- apply( phyloMat, 1:2, function(i) as.numeric( i > 0) )
I0 <- diag(1, dim(data)[1] )
rownames(I0) <- colnames(I0) <- data$species 
 I <- diag(1 / data$N_nests )
 
I <- I / max(I)
rownames(I) <- colnames(I) <- data$species 

# Form a matrix representing species identity
m <- as.matrix( model.matrix( ~ species-1, data = data) )
S <- crossprod(t(m), t(m) )
rownames(S) <- colnames(S) <- data$species 


Model_12 <- lmekin( TPR ~ (1|species) + mean_year + log( N_nests), varlist = list( I, phyloMat, distanceMatrix), data = data )
Model_12

par(mfrow = c(1, 2))
plot(density(resid(Model_12)))
qqnorm(resid(Model_12))
qqline(resid(Model_12))
par(mfrow = c(1, 1))
## - check for data normality -> ok








### -----------------------------------------------
### - Fig. 2C; Table S3. --- Robustness of temporal trend in daily nest predation to shorebird clades and daily nest predation computation method
### -----------------------------------------------

# whole dataset computation is the same as previously (model 1)

### CHARADRIIDAE first

data <- read.csv( "DATApopulationsCHAR.csv", sep=";")

# Create phylogenetic geographic and PI matrices
phyloMat <- vcv.phylo( tree2 )
phyloMat <- phyloMat / max( phyloMat )
distanceMatrix <- dist.mat( data$Latitude, data$Longitude, data$species ) 

diag( distanceMatrix ) <- diag(distanceMatrix) + 0.01
distanceMatrix <- distanceMatrix / 1.01 
idxMat <- apply( phyloMat, 1:2, function(i) as.numeric( i > 0) )
I0 <- diag(1, dim(data)[1] )
rownames(I0) <- colnames(I0) <- data$species 
 I <- diag(1 / data$N_nests )
 
I <- I / max(I)
rownames(I) <- colnames(I) <- data$species 

# Form a matrix representing species identity
m <- as.matrix( model.matrix( ~ species-1, data = data) )
S <- crossprod(t(m), t(m) )
rownames(S) <- colnames(S) <- data$species 


Model_13 <- lmekin( log(DPR) ~ (1|species) + mean_year + log( N_nests), varlist = list( I, phyloMat, distanceMatrix), data = data )
Model_13

par(mfrow = c(1, 2))
plot(density(resid(Model_13)))
qqnorm(resid(Model_13))
qqline(resid(Model_13))
par(mfrow = c(1, 1))
## - check for data normality -> ok


### SCOLOPACIDAE second

data <- read.csv( "DATApopulationsSCOL.csv", sep=";")

# Create phylogenetic geographic and PI matrices
phyloMat <- vcv.phylo( tree2 )
phyloMat <- phyloMat / max( phyloMat )
distanceMatrix <- dist.mat( data$Latitude, data$Longitude, data$species ) 

diag( distanceMatrix ) <- diag(distanceMatrix) + 0.01
distanceMatrix <- distanceMatrix / 1.01 
idxMat <- apply( phyloMat, 1:2, function(i) as.numeric( i > 0) )
I0 <- diag(1, dim(data)[1] )
rownames(I0) <- colnames(I0) <- data$species 
 I <- diag(1 / data$N_nests )
 
I <- I / max(I)
rownames(I) <- colnames(I) <- data$species 

# Form a matrix representing species identity
m <- as.matrix( model.matrix( ~ species-1, data = data) )
S <- crossprod(t(m), t(m) )
rownames(S) <- colnames(S) <- data$species 


Model_14 <- lmekin( log(DPR) ~ (1|species) + mean_year + log( N_nests), varlist = list( I, phyloMat, distanceMatrix), data = data )
Model_14

par(mfrow = c(1, 2))
plot(density(resid(Model_14)))
qqnorm(resid(Model_14))
qqline(resid(Model_14))
par(mfrow = c(1, 1))
## - check for data normality -> ok


### -----------------------------------------------
### - Fig. 2D; Table S3. --- Robustness of temporal trend in total nest predation to shorebird clades and daily nest predation computation method
### -----------------------------------------------

# whole dataset computation is the same as previously (model 7)

### CHARADRII first

data <- read.csv( "DATApopulationsCHAR.csv", sep=";")

# Create phylogenetic geographic and PI matrices
phyloMat <- vcv.phylo( tree2 )
phyloMat <- phyloMat / max( phyloMat )
distanceMatrix <- dist.mat( data$Latitude, data$Longitude, data$species ) 

diag( distanceMatrix ) <- diag(distanceMatrix) + 0.01
distanceMatrix <- distanceMatrix / 1.01 
idxMat <- apply( phyloMat, 1:2, function(i) as.numeric( i > 0) )
I0 <- diag(1, dim(data)[1] )
rownames(I0) <- colnames(I0) <- data$species 
 I <- diag(1 / data$N_nests )
 
I <- I / max(I)
rownames(I) <- colnames(I) <- data$species 

# Form a matrix representing species identity
m <- as.matrix( model.matrix( ~ species-1, data = data) )
S <- crossprod(t(m), t(m) )
rownames(S) <- colnames(S) <- data$species 


Model_15 <- lmekin( TPR ~ (1|species) + mean_year + log( N_nests), varlist = list( I, phyloMat, distanceMatrix), data = data )
Model_15

par(mfrow = c(1, 2))
plot(density(resid(Model_15)))
qqnorm(resid(Model_15))
qqline(resid(Model_15))
par(mfrow = c(1, 1))
## - check for data normality -> ok


### SCOLOPACI second

data <- read.csv( "DATApopulationsSCOL.csv", sep=";")

# Create phylogenetic geographic and PI matrices
phyloMat <- vcv.phylo( tree2 )
phyloMat <- phyloMat / max( phyloMat )
distanceMatrix <- dist.mat( data$Latitude, data$Longitude, data$species ) 

diag( distanceMatrix ) <- diag(distanceMatrix) + 0.01
distanceMatrix <- distanceMatrix / 1.01 
idxMat <- apply( phyloMat, 1:2, function(i) as.numeric( i > 0) )
I0 <- diag(1, dim(data)[1] )
rownames(I0) <- colnames(I0) <- data$species 
 I <- diag(1 / data$N_nests )
 
I <- I / max(I)
rownames(I) <- colnames(I) <- data$species 

# Form a matrix representing species identity
m <- as.matrix( model.matrix( ~ species-1, data = data) )
S <- crossprod(t(m), t(m) )
rownames(S) <- colnames(S) <- data$species 


Model_16 <- lmekin( TPR ~ (1|species) + mean_year + log( N_nests), varlist = list( I, phyloMat, distanceMatrix), data = data )
Model_16

par(mfrow = c(1, 2))
plot(density(resid(Model_16)))
qqnorm(resid(Model_16))
qqline(resid(Model_16))
par(mfrow = c(1, 1))
## - check for data normality -> ok




### -----------------------------------------------
### - Table S3. --- Robustness of temporal trend in total nest predation to shorebird clades and daily nest predation computation method - no figure --- method conversion check only
### -----------------------------------------------


### TPR first, then DPR, all 4 computations are fine

data <- read.csv( "DATApopulations_computed.csv", sep=";")

# Create phylogenetic geographic and PI matrices
phyloMat <- vcv.phylo( tree2 )
phyloMat <- phyloMat / max( phyloMat )
distanceMatrix <- dist.mat( data$Latitude, data$Longitude, data$species ) 

diag( distanceMatrix ) <- diag(distanceMatrix) + 0.01
distanceMatrix <- distanceMatrix / 1.01 
idxMat <- apply( phyloMat, 1:2, function(i) as.numeric( i > 0) )
I0 <- diag(1, dim(data)[1] )
rownames(I0) <- colnames(I0) <- data$species 
 I <- diag(1 / data$N_nests )
 
I <- I / max(I)
rownames(I) <- colnames(I) <- data$species 

# Form a matrix representing species identity
m <- as.matrix( model.matrix( ~ species-1, data = data) )
S <- crossprod(t(m), t(m) )
rownames(S) <- colnames(S) <- data$species 


Model_17 <- lmekin( TPR ~ (1|species) + mean_year + log( N_nests), varlist = list( I, phyloMat, distanceMatrix), data = data )
Model_17

par(mfrow = c(1, 2))
plot(density(resid(Model_17)))
qqnorm(resid(Model_17))
qqline(resid(Model_17))
par(mfrow = c(1, 1))
## - check for data normality -> ok



data <- read.csv( "DATApopulations_given.csv", sep=";")

# Create phylogenetic geographic and PI matrices
phyloMat <- vcv.phylo( tree2 )
phyloMat <- phyloMat / max( phyloMat )
distanceMatrix <- dist.mat( data$Latitude, data$Longitude, data$species ) 

diag( distanceMatrix ) <- diag(distanceMatrix) + 0.01
distanceMatrix <- distanceMatrix / 1.01 
idxMat <- apply( phyloMat, 1:2, function(i) as.numeric( i > 0) )
I0 <- diag(1, dim(data)[1] )
rownames(I0) <- colnames(I0) <- data$species 
 I <- diag(1 / data$N_nests )
 
I <- I / max(I)
rownames(I) <- colnames(I) <- data$species 

# Form a matrix representing species identity
m <- as.matrix( model.matrix( ~ species-1, data = data) )
S <- crossprod(t(m), t(m) )
rownames(S) <- colnames(S) <- data$species 


Model_18 <- lmekin( TPR ~ (1|species) + mean_year + log( N_nests), varlist = list( I, phyloMat, distanceMatrix), data = data )
Model_18

par(mfrow = c(1, 2))
plot(density(resid(Model_18)))
qqnorm(resid(Model_18))
qqline(resid(Model_18))
par(mfrow = c(1, 1))
## - check for data normality -> ok



data <- read.csv( "DATApopulations_computed.csv", sep=";")

# Create phylogenetic geographic and PI matrices
phyloMat <- vcv.phylo( tree2 )
phyloMat <- phyloMat / max( phyloMat )
distanceMatrix <- dist.mat( data$Latitude, data$Longitude, data$species ) 

diag( distanceMatrix ) <- diag(distanceMatrix) + 0.01
distanceMatrix <- distanceMatrix / 1.01 
idxMat <- apply( phyloMat, 1:2, function(i) as.numeric( i > 0) )
I0 <- diag(1, dim(data)[1] )
rownames(I0) <- colnames(I0) <- data$species 
 I <- diag(1 / data$N_nests )
 
I <- I / max(I)
rownames(I) <- colnames(I) <- data$species 

# Form a matrix representing species identity
m <- as.matrix( model.matrix( ~ species-1, data = data) )
S <- crossprod(t(m), t(m) )
rownames(S) <- colnames(S) <- data$species 


Model_19 <- lmekin( log(DPR) ~ (1|species) + mean_year + log( N_nests), varlist = list( I, phyloMat, distanceMatrix), data = data )
Model_19

par(mfrow = c(1, 2))
plot(density(resid(Model_19)))
qqnorm(resid(Model_19))
qqline(resid(Model_19))
par(mfrow = c(1, 1))
## - check for data normality -> ok



data <- read.csv( "DATApopulations_given.csv", sep=";")

# Create phylogenetic geographic and PI matrices
phyloMat <- vcv.phylo( tree2 )
phyloMat <- phyloMat / max( phyloMat )
distanceMatrix <- dist.mat( data$Latitude, data$Longitude, data$species ) 

diag( distanceMatrix ) <- diag(distanceMatrix) + 0.01
distanceMatrix <- distanceMatrix / 1.01 
idxMat <- apply( phyloMat, 1:2, function(i) as.numeric( i > 0) )
I0 <- diag(1, dim(data)[1] )
rownames(I0) <- colnames(I0) <- data$species 
 I <- diag(1 / data$N_nests )
 
I <- I / max(I)
rownames(I) <- colnames(I) <- data$species 

# Form a matrix representing species identity
m <- as.matrix( model.matrix( ~ species-1, data = data) )
S <- crossprod(t(m), t(m) )
rownames(S) <- colnames(S) <- data$species 


Model_20 <- lmekin( log(DPR) ~ (1|species) + mean_year + log( N_nests), varlist = list( I, phyloMat, distanceMatrix), data = data )
Model_20

par(mfrow = c(1, 2))
plot(density(resid(Model_20)))
qqnorm(resid(Model_20))
qqline(resid(Model_20))
par(mfrow = c(1, 1))
## - check for data normality -> ok




### -----------------------------------------------
### - Fig. 2E; Table S5. --- Within-population variation in historic and recent nest predation - statistics. --- daily nest predation 
### -----------------------------------------------

data <- read.csv( "Fig.2d.csv", sep=";")

data$spec_nr<- as.factor(data$spec_nr)
data$period<- as.factor(data$period)


library(lme4)

# model 21

dpr.2000<-lmer(log(DPR)~period+Latitude+(1|spec_nr)+(1|Loc_nr), data=data)
drop1(dpr.2000,~.,test="Chisq")

summary(dpr.2000)

par(mfrow = c(1, 2))
plot(density(resid(dpr.2000)))
qqnorm(resid(dpr.2000))
qqline(resid(dpr.2000))
par(mfrow = c(1, 1))
## - check for data normality -> ok


### -----------------------------------------------
### - Fig. 2F; Table S5. --- Within-population variation in historic and recent nest predation - statistics. --- total nest predation 
### -----------------------------------------------


# model 22

dpr.2000<-lmer(TPR~period+Latitude+(1|spec_nr)+(1|Loc_nr), data=data)
drop1(dpr.2000,~.,test="Chisq")

summary(dpr.2000)

par(mfrow = c(1, 2))
plot(density(resid(dpr.2000)))
qqnorm(resid(dpr.2000))
qqline(resid(dpr.2000))
par(mfrow = c(1, 1))
## - check for data normality -> ok




### -----------------------------------------------
### - Fig. 2A, 3A ; Table S6. Effect of latitude (A, B and C) and time (A) on nest predation --- daily nest predation rate - spatial and temporal patterns in one model
### -----------------------------------------------

# all DPR values in the data are changed to original DPR + 0.01 to be able to use log(DPR) which is needed for data distribution normality.

data <- read.csv( "DATApopulations.csv", sep=";")

#  Create phylogenetic geographic and PI matrices
phyloMat <- vcv.phylo( tree2 )
phyloMat <- phyloMat / max( phyloMat )
distanceMatrix <- dist.mat( data$Latitude, data$Longitude, data$species ) 
diag( distanceMatrix ) <- diag(distanceMatrix) + 0.01
distanceMatrix <- distanceMatrix / 1.01

idxMat <- apply( phyloMat, 1:2, function(i) as.numeric( i > 0) )


I0 <- diag(1, dim(data)[1] )
rownames(I0) <- colnames(I0) <- data$species 
 I <- diag(1 / data$N_nests )
 
I <- I / max(I)
rownames(I) <- colnames(I) <- data$species 


# Form a matrix representing species identity
m <- as.matrix( model.matrix( ~ species-1, data = data) )
S <- crossprod(t(m), t(m) )
rownames(S) <- colnames(S) <- data$species 

# Create a latitude variable

data$NS <- data$Latitude > 0



model_x <- lmekin( log(DPR) ~ (1|species) + log( N_nests) + mean_year * NS * abs( Latitude ), varlist = list( I, phyloMat, distanceMatrix), data = data )
model_x


# next deleting nonsignificant interactions

model_23 <- lmekin( log(DPR) ~ (1|species) + log( N_nests) + mean_year + NS + abs( Latitude ) + mean_year : NS + NS : abs( Latitude ) + mean_year : abs( Latitude ), varlist = list( I, phyloMat, distanceMatrix), data = data )
model_23

par(mfrow = c(1, 2))
plot(density(resid(model_23)))
qqnorm(resid(model_23))
qqline(resid(model_23))
par(mfrow = c(1, 1))
## - check for data normality - ok



model_24 <- lmekin( log(DPR) ~ (1|species) + log( N_nests) + mean_year + NS + abs( Latitude ) + NS : abs( Latitude ) + mean_year : abs( Latitude ), varlist = list( I, phyloMat, distanceMatrix), data = data )
model_24

par(mfrow = c(1, 2))
plot(density(resid(model_24)))
qqnorm(resid(model_24))
qqline(resid(model_24))
par(mfrow = c(1, 1))
## - check for data normality - ok


model_25 <- lmekin( log(DPR) ~ (1|species) + log( N_nests) + mean_year + NS + abs( Latitude ) + mean_year : abs( Latitude ), varlist = list( I, phyloMat, distanceMatrix), data = data )
model_25

par(mfrow = c(1, 2))
plot(density(resid(model_25)))
qqnorm(resid(model_25))
qqline(resid(model_25))
par(mfrow = c(1, 1))
## - check for data normality - ok



# interaction are non-significant, now we will address main factors only

model_26 <- lmekin( log(DPR) ~ (1|species) + log( N_nests) + mean_year + NS + abs( Latitude ), varlist = list( I, phyloMat, distanceMatrix), data = data )
model_26


par(mfrow = c(1, 2))
plot(density(resid(model_26)))
qqnorm(resid(model_26))
qqline(resid(model_26))
par(mfrow = c(1, 1))
## - check for data normality - ok



### -----------------------------------------------
### - Fig. 3A; Table S6. Effect of latitude (A, B and C) and time (A) on nest predation --- daily nest predation rate - HISTORIC (1944-1999) and RECENT (2000-2016) data
### -----------------------------------------------

### HISTORIC DATA

data <- read.csv( "Before2000.csv", sep=";")

#  Create phylogenetic geographic and PI matrices
phyloMat <- vcv.phylo( tree2 )
phyloMat <- phyloMat / max( phyloMat )
distanceMatrix <- dist.mat( data$Latitude, data$Longitude, data$species ) 
diag( distanceMatrix ) <- diag(distanceMatrix) + 0.01
distanceMatrix <- distanceMatrix / 1.01

idxMat <- apply( phyloMat, 1:2, function(i) as.numeric( i > 0) )


I0 <- diag(1, dim(data)[1] )
rownames(I0) <- colnames(I0) <- data$species 
 I <- diag(1 / data$N_nests )
 
I <- I / max(I)
rownames(I) <- colnames(I) <- data$species 


# Form a matrix representing species identity
m <- as.matrix( model.matrix( ~ species-1, data = data) )
S <- crossprod(t(m), t(m) )
rownames(S) <- colnames(S) <- data$species 

# Create a latitude variable

data$NS <- data$Latitude > 0


hist(data$DPR_orig)
# histogram of original daily predation rates, log transformation is really needed


model_27  <- lmekin( log(DPR) ~ (1|species) + log( N_nests) + NS + abs( Latitude ) + NS : abs( Latitude ), varlist = list( I, phyloMat, distanceMatrix), data = data )
model_27

par(mfrow = c(1, 2))
plot(density(resid(model_27)))
qqnorm(resid(model_27))
qqline(resid(model_27))
par(mfrow = c(1, 1))
## - check for data normality - ok


# without interaction

model_28  <- lmekin( log(DPR) ~ (1|species) + log( N_nests) + NS + abs( Latitude ), varlist = list( I, phyloMat, distanceMatrix), data = data )
model_28

par(mfrow = c(1, 2))
plot(density(resid(model_28)))
qqnorm(resid(model_28))
qqline(resid(model_28))
par(mfrow = c(1, 1))
## - check for data normality - ok



### RECENT DATA

data <- read.csv( "After2000.csv", sep=";")

#  Create phylogenetic geographic and PI matrices
phyloMat <- vcv.phylo( tree2 )
phyloMat <- phyloMat / max( phyloMat )
distanceMatrix <- dist.mat( data$Latitude, data$Longitude, data$species ) 
diag( distanceMatrix ) <- diag(distanceMatrix) + 0.01
distanceMatrix <- distanceMatrix / 1.01

idxMat <- apply( phyloMat, 1:2, function(i) as.numeric( i > 0) )


I0 <- diag(1, dim(data)[1] )
rownames(I0) <- colnames(I0) <- data$species 
 I <- diag(1 / data$N_nests )
 
I <- I / max(I)
rownames(I) <- colnames(I) <- data$species 


# Form a matrix representing species identity
m <- as.matrix( model.matrix( ~ species-1, data = data) )
S <- crossprod(t(m), t(m) )
rownames(S) <- colnames(S) <- data$species 

# Create a latitude variable

data$NS <- data$Latitude > 0



model_29  <- lmekin( log(DPR) ~ (1|species) + log( N_nests) + NS + abs( Latitude ) + NS : abs( Latitude ), varlist = list( I, phyloMat, distanceMatrix), data = data )
model_29

par(mfrow = c(1, 2))
plot(density(resid(model_29)))
qqnorm(resid(model_29))
qqline(resid(model_29))
par(mfrow = c(1, 1))
## - check for data normality -> ok


# interaction is significant, but now we still need to test main effects in separate model:


model_30  <- lmekin( log(DPR) ~ (1|species) + log( N_nests) + NS + abs( Latitude ), varlist = list( I, phyloMat, distanceMatrix), data = data )
model_30

par(mfrow = c(1, 2))
plot(density(resid(model_30)))
qqnorm(resid(model_30))
qqline(resid(model_30))
par(mfrow = c(1, 1))
## - check for data normality -> ok




### -----------------------------------------------
### - Fig. 2B, 3B ; Table S6. Effect of latitude (A, B and C) and time (A) on nest predation --- total nest predation rate - spatial and temporal patterns in one model
### -----------------------------------------------

### All data first 

data <- read.csv( "DATApopulations.csv", sep=";")

#  Create phylogenetic geographic and PI matrices
phyloMat <- vcv.phylo( tree2 )
phyloMat <- phyloMat / max( phyloMat )
distanceMatrix <- dist.mat( data$Latitude, data$Longitude, data$species ) 
diag( distanceMatrix ) <- diag(distanceMatrix) + 0.01
distanceMatrix <- distanceMatrix / 1.01

idxMat <- apply( phyloMat, 1:2, function(i) as.numeric( i > 0) )


I0 <- diag(1, dim(data)[1] )
rownames(I0) <- colnames(I0) <- data$species 
 I <- diag(1 / data$N_nests )
 
I <- I / max(I)
rownames(I) <- colnames(I) <- data$species 


# Form a matrix representing species identity
m <- as.matrix( model.matrix( ~ species-1, data = data) )
S <- crossprod(t(m), t(m) )
rownames(S) <- colnames(S) <- data$species 

# Create a latitude variable

data$NS <- data$Latitude > 0


# all TPR values in the data are original, no transformation



model_y <- lmekin( TPR ~ (1|species) + log( N_nests) + mean_year * NS * abs( Latitude ), varlist = list( I, phyloMat, distanceMatrix), data = data )
model_y


# next deleting of nonsignificant interactions

model_31 <- lmekin( TPR ~ (1|species) + log( N_nests) + mean_year + NS + abs( Latitude ) + mean_year : NS + NS : abs( Latitude ) + mean_year : abs( Latitude ), varlist = list( I, phyloMat, distanceMatrix), data = data )
model_31

par(mfrow = c(1, 2))
plot(density(resid(model_31)))
qqnorm(resid(model_31))
qqline(resid(model_31))
par(mfrow = c(1, 1))
## - check for data normality -> ok


model_32 <- lmekin( TPR ~ (1|species) + log( N_nests) + mean_year + NS + abs( Latitude ) + NS : abs( Latitude ) + mean_year : abs( Latitude ), varlist = list( I, phyloMat, distanceMatrix), data = data )
model_32

par(mfrow = c(1, 2))
plot(density(resid(model_32)))
qqnorm(resid(model_32))
qqline(resid(model_32))
par(mfrow = c(1, 1))
## - check for data normality -> ok


model_33 <- lmekin( TPR ~ (1|species) + log( N_nests) + mean_year + NS + abs( Latitude ) + mean_year : abs( Latitude ), varlist = list( I, phyloMat, distanceMatrix), data = data )
model_33

par(mfrow = c(1, 2))
plot(density(resid(model_33)))
qqnorm(resid(model_33))
qqline(resid(model_33))
par(mfrow = c(1, 1))
## - check for data normality -> ok


# interaction are nonsignificant, now we will address main factors only

model_34 <- lmekin( TPR ~ (1|species) + log( N_nests) + mean_year + NS + abs( Latitude ), varlist = list( I, phyloMat, distanceMatrix), data = data )
model_34

par(mfrow = c(1, 2))
plot(density(resid(model_34)))
qqnorm(resid(model_34))
qqline(resid(model_34))
par(mfrow = c(1, 1))
## - check for data normality -> ok




### -----------------------------------------------
### - Fig. 3B; Table S6. Effect of latitude (A, B and C) and time (A) on nest predation --- total nest predation rate - HISTORIC (1944-1999) and RECENT (2000-2016) data
### -----------------------------------------------

### HISTORIC DATA

data <- read.csv( "Before2000.csv", sep=";")

#  Create phylogenetic geographic and PI matrices
phyloMat <- vcv.phylo( tree2 )
phyloMat <- phyloMat / max( phyloMat )
distanceMatrix <- dist.mat( data$Latitude, data$Longitude, data$species ) 
diag( distanceMatrix ) <- diag(distanceMatrix) + 0.01
distanceMatrix <- distanceMatrix / 1.01

idxMat <- apply( phyloMat, 1:2, function(i) as.numeric( i > 0) )


I0 <- diag(1, dim(data)[1] )
rownames(I0) <- colnames(I0) <- data$species 
 I <- diag(1 / data$N_nests )
 
I <- I / max(I)
rownames(I) <- colnames(I) <- data$species 


# Form a matrix representing species identity
m <- as.matrix( model.matrix( ~ species-1, data = data) )
S <- crossprod(t(m), t(m) )
rownames(S) <- colnames(S) <- data$species 

# Create a latitude variable

data$NS <- data$Latitude > 0


model_35  <- lmekin( TPR_orig ~ (1|species) + log( N_nests) + NS + abs( Latitude ) + NS : abs( Latitude ), varlist = list( I, phyloMat, distanceMatrix), data = data )
model_35

par(mfrow = c(1, 2))
plot(density(resid(model_35)))
qqnorm(resid(model_35))
qqline(resid(model_35))
par(mfrow = c(1, 1))
## - check for data normality -> ok


# without interaction

model_36  <- lmekin( TPR_orig ~ (1|species) + log( N_nests) + NS + abs( Latitude ), varlist = list( I, phyloMat, distanceMatrix), data = data )
model_36

par(mfrow = c(1, 2))
plot(density(resid(model_36)))
qqnorm(resid(model_36))
qqline(resid(model_36))
par(mfrow = c(1, 1))
## - check for data normality -> ok




### RECENT DATA

data <- read.csv( "After2000.csv", sep=";")

#  Create phylogenetic geographic and PI matrices
phyloMat <- vcv.phylo( tree2 )
phyloMat <- phyloMat / max( phyloMat )
distanceMatrix <- dist.mat( data$Latitude, data$Longitude, data$species ) 
diag( distanceMatrix ) <- diag(distanceMatrix) + 0.01
distanceMatrix <- distanceMatrix / 1.01

idxMat <- apply( phyloMat, 1:2, function(i) as.numeric( i > 0) )


I0 <- diag(1, dim(data)[1] )
rownames(I0) <- colnames(I0) <- data$species 
 I <- diag(1 / data$N_nests )
 
I <- I / max(I)
rownames(I) <- colnames(I) <- data$species 


# Form a matrix representing species identity
m <- as.matrix( model.matrix( ~ species-1, data = data) )
S <- crossprod(t(m), t(m) )
rownames(S) <- colnames(S) <- data$species 

# Create a latitude variable

data$NS <- data$Latitude > 0



model_37  <- lmekin( TPR_orig ~ (1|species) + log( N_nests) + NS + abs( Latitude ) + NS : abs( Latitude ), varlist = list( I, phyloMat, distanceMatrix), data = data )
model_37

par(mfrow = c(1, 2))
plot(density(resid(model_37)))
qqnorm(resid(model_37))
qqline(resid(model_37))
par(mfrow = c(1, 1))
## - check for data normality -> obviously ok


# interaction is significant, but I still need to test main effects in separate model:

model_38  <- lmekin( TPR_orig ~ (1|species) + log( N_nests) + NS + abs( Latitude ), varlist = list( I, phyloMat, distanceMatrix), data = data )
model_38

par(mfrow = c(1, 2))
plot(density(resid(model_38)))
qqnorm(resid(model_38))
qqline(resid(model_38))
par(mfrow = c(1, 1))
## - check for data normality -> ok






### -----------------------------------------------
### - Fig. 4 - CLIMATIC DATA COMPUTATION - Table S7. Climate change in relation to nest predation, Table S8. Correlation matrix of four potential predictors of nest predation. 
### -----------------------------------------------

#### - Climatic data - correlation matrix with other variables

data <- read.csv( "Clima_corr_matrix.csv",  h = T)
summary(data)
cor(data)

# table of correlations


hist(data$Latitude)
hist(data$Year)
hist(data$Temp_slope_30)
hist(data$Temp_sd_30)

# only Temp_slope_30 has normal distribution, therefore I use Spearman test for obtaining P-values

# Firstly run everything until "data$NS <- data$Latitude > 0"

data <- read.csv( "WN_withclima_complete_2018.csv", h = T)
summary(data)

#  Create phylogenetic geographic and PI matrices
phyloMat <- vcv.phylo( tree2 )
phyloMat <- phyloMat / max( phyloMat )
distanceMatrix <- dist.mat( data$Latitude, data$Longitude, data$species ) 
diag( distanceMatrix ) <- diag(distanceMatrix) + 0.01
distanceMatrix <- distanceMatrix / 1.01

idxMat <- apply( phyloMat, 1:2, function(i) as.numeric( i > 0) )


I0 <- diag(1, dim(data)[1] )
rownames(I0) <- colnames(I0) <- data$species 
 I <- diag(1 / data$N_nests )
 
I <- I / max(I)
rownames(I) <- colnames(I) <- data$species 


# Form a matrix representing species identity
m <- as.matrix( model.matrix( ~ species-1, data = data) )
S <- crossprod(t(m), t(m) )
rownames(S) <- colnames(S) <- data$species 

# Create a latitude variable

data$NS <- data$Latitude > 0


attach(data)

### CORRELATION TESTS

plot(mean_year,temp_slope_30)
abline(lm(temp_slope_30~mean_year), col="red")

cor(mean_year,temp_slope_30)
cor.test(mean_year,temp_slope_30, method="s")
# - they are highly correlated, therefore I am going to omit "mean_year", the variable which we are not interested in right now.


plot(Latitude,temp_slope_30)
abline(lm(temp_slope_30~Latitude), col="red")

cor(Latitude,temp_slope_30)
cor.test(Latitude,temp_slope_30, method="s")
# - they are correlated, therefore I am going to omit "Latitude", the variable which we are not interested in right now.


plot(mean_year,temp_sd_30)
abline(lm(temp_sd_30~mean_year), col="red")

cor(mean_year,temp_sd_30)
cor.test(mean_year,temp_sd_30, method="s")
# - they are  correlated, therefore I am going to omit "mean_year", the variable which we are not interested in right now.


plot(Latitude,temp_sd_30)
abline(lm(temp_sd_30~Latitude), col="red")

cor(Latitude,temp_sd_30)
cor.test(Latitude,temp_sd_30, method="s")
# - they are highly correlated, therefore I am going to omit "Latitude", the variable which we are not interested in right now.


plot(temp_slope_30,temp_sd_30)
abline(lm(temp_sd_30~temp_slope_30), col="red")

cor(temp_slope_30,temp_sd_30)
cor.test(temp_slope_30,temp_sd_30, method="s")
# - they are highly correlated, therefore I am going to address these variables in separate models.


plot(mean_year,Latitude)
abline(lm(Latitude~mean_year), col="red")

cor(mean_year,Latitude)
cor.test(mean_year,Latitude, method="s")
# - no correlation here, these variables can be used together in one model

detach(data)

# other variables can not be together in one model, therefore we will test climatic variables in separate simple models



### DAILY NEST PREDATION

model_39 <- lmekin( log(DPR) ~ (1|species) + log( N_nests) + temp_slope_30, varlist = list( I, phyloMat, distanceMatrix), data = data )
model_39

par(mfrow = c(1, 2))
plot(density(resid(model_39)))
qqnorm(resid(model_39))
qqline(resid(model_39))
par(mfrow = c(1, 1))
## - check for data normality - ok

# -> temperature slope affects the DPR and N_nests not



model_40 <- lmekin( log(DPR) ~ (1|species) + log( N_nests) + temp_slope_40, varlist = list( I, phyloMat, distanceMatrix), data = data )
model_40

par(mfrow = c(1, 2))
plot(density(resid(model_40)))
qqnorm(resid(model_40))
qqline(resid(model_40))
par(mfrow = c(1, 1))
## - check for data normality - ok

# -> temperature slope affects the DPR and N_nests not


model_41 <- lmekin( log(DPR) ~ (1|species) + log( N_nests) + temp_slope_20, varlist = list( I, phyloMat, distanceMatrix), data = data )
model_41

par(mfrow = c(1, 2))
plot(density(resid(model_41)))
qqnorm(resid(model_41))
qqline(resid(model_41))
par(mfrow = c(1, 1))
## - check for data normality - ok

# -> temperature slope affects the DPR and N_nests not


model_42 <- lmekin( log(DPR) ~ (1|species) + log( N_nests) + temp_slope_10, varlist = list( I, phyloMat, distanceMatrix), data = data )
model_42

par(mfrow = c(1, 2))
plot(density(resid(model_42)))
qqnorm(resid(model_42))
qqline(resid(model_42))
par(mfrow = c(1, 1))
## - check for data normality - ok

# -> temperature slope is not affecting DPR as well as N_nests



### standart deviation

model_43 <- lmekin( log(DPR) ~ (1|species) + log( N_nests) + temp_sd_30, varlist = list( I, phyloMat, distanceMatrix), data = data )
model_43

par(mfrow = c(1, 2))
plot(density(resid(model_43)))
qqnorm(resid(model_43))
qqline(resid(model_43))
par(mfrow = c(1, 1))
## - check for data normality - ok

# -> temperature sd affects the DPR and N_nests not


model_44 <- lmekin( log(DPR) ~ (1|species) + log( N_nests) + temp_sd_40, varlist = list( I, phyloMat, distanceMatrix), data = data )
model_44

par(mfrow = c(1, 2))
plot(density(resid(model_44)))
qqnorm(resid(model_44))
qqline(resid(model_44))
par(mfrow = c(1, 1))
## - check for data normality - ok

# -> temperature sd affects the DPR and N_nests not



model_45 <- lmekin( log(DPR) ~ (1|species) + log( N_nests) + temp_sd_20, varlist = list( I, phyloMat, distanceMatrix), data = data )
model_45

par(mfrow = c(1, 2))
plot(density(resid(model_45)))
qqnorm(resid(model_45))
qqline(resid(model_45))
par(mfrow = c(1, 1))
## - check for data normality - ok

# -> temperature sd affects the DPR and N_nests not



model_46 <- lmekin( log(DPR) ~ (1|species) + log( N_nests) + temp_sd_10, varlist = list( I, phyloMat, distanceMatrix), data = data )
model_46

par(mfrow = c(1, 2))
plot(density(resid(model_46)))
qqnorm(resid(model_46))
qqline(resid(model_46))
par(mfrow = c(1, 1))
## - check for data normality - ok

# -> temperature sd does not affect the DPR as well as N_nests not




### TOTAL NEST PREDATION


model_47 <- lmekin( TPR_orig ~ (1|species) + log( N_nests) + temp_slope_30, varlist = list( I, phyloMat, distanceMatrix), data = data )
model_47

par(mfrow = c(1, 2))
plot(density(resid(model_47)))
qqnorm(resid(model_47))
qqline(resid(model_47))
par(mfrow = c(1, 1))
## - check for data normality - ok

# -> temperature slope affects the TPR and N_nests not


model_48 <- lmekin( TPR_orig ~ (1|species) + log( N_nests) + temp_slope_40, varlist = list( I, phyloMat, distanceMatrix), data = data )
model_48

par(mfrow = c(1, 2))
plot(density(resid(model_48)))
qqnorm(resid(model_48))
qqline(resid(model_48))
par(mfrow = c(1, 1))
## - check for data normality - ok

# -> temperature slope affects the TPR and N_nests not


model_49 <- lmekin( TPR_orig ~ (1|species) + log( N_nests) + temp_slope_20, varlist = list( I, phyloMat, distanceMatrix), data = data )
model_49

par(mfrow = c(1, 2))
plot(density(resid(model_49)))
qqnorm(resid(model_49))
qqline(resid(model_49))
par(mfrow = c(1, 1))
## - check for data normality - ok

# -> temperature slope affects the TPR and N_nests not



model_50 <- lmekin( TPR_orig ~ (1|species) + log( N_nests) + temp_slope_10, varlist = list( I, phyloMat, distanceMatrix), data = data )
model_50

par(mfrow = c(1, 2))
plot(density(resid(model_50)))
qqnorm(resid(model_50))
qqline(resid(model_50))
par(mfrow = c(1, 1))
## - check for data normality - ok

# -> temperature slope does not affects the TPR as well as N_nests




### standart deviation


model_51 <- lmekin( TPR_orig ~ (1|species) + log( N_nests) + temp_sd_30, varlist = list( I, phyloMat, distanceMatrix), data = data )
model_51

par(mfrow = c(1, 2))
plot(density(resid(model_51)))
qqnorm(resid(model_51))
qqline(resid(model_51))
par(mfrow = c(1, 1))
## - check for data normality - ok

# -> temperature sd affects the TPR and N_nests not


model_52 <- lmekin( TPR_orig ~ (1|species) + log( N_nests) + temp_sd_40, varlist = list( I, phyloMat, distanceMatrix), data = data )
model_52

par(mfrow = c(1, 2))
plot(density(resid(model_52)))
qqnorm(resid(model_52))
qqline(resid(model_52))
par(mfrow = c(1, 1))
## - check for data normality - ok

# -> temperature sd affects the TPR and N_nests not


model_53 <- lmekin( TPR_orig ~ (1|species) + log( N_nests) + temp_sd_20, varlist = list( I, phyloMat, distanceMatrix), data = data )
model_53

par(mfrow = c(1, 2))
plot(density(resid(model_53)))
qqnorm(resid(model_53))
qqline(resid(model_53))
par(mfrow = c(1, 1))
## - check for data normality - ok

# -> temperature sd does not affect the TPR as well as N_nests


model_54 <- lmekin( TPR_orig ~ (1|species) + log( N_nests) + temp_sd_10, varlist = list( I, phyloMat, distanceMatrix), data = data )
model_54

par(mfrow = c(1, 2))
plot(density(resid(model_54)))
qqnorm(resid(model_54))
qqline(resid(model_54))
par(mfrow = c(1, 1))
## - check for data normality - ok

# -> temperature sd does not affect the TPR as well as N_nests 



######## appendix - method conversion check - described in Materials and Methods - no table

data <- read.csv( "Conversion_check.csv", sep=";")
summary(data)

hist(data$DPR_Beintema)
hist(data$DPR_orig)


hist(log(data$DPR_orig))
hist(log(data$DPR_Beintema) )

cor.test(log(data$DPR_Beintema), log(data$DPR_orig), type="pearson")

t.test(log(data$DPR_orig), log(data$DPR_Beintema), paired=TRUE)






# ------------------------------------------------
# ------- An example using multiple trees -------- 
# -- first, create a list of phylogeny covariance matrices --- 
phyloMats <- lapply( trees2, vcv.phylo, corr = TRUE) 


### -----------------------------------------------
### - Fig. 2A, 3A ; Table S6. Effect of latitude (A, B and C) and time (A) on nest predation --- daily nest predation rate - spatial and temporal patterns in one model
### -----------------------------------------------

# all DPR values in the data are changed to original DPR + 0.01 to be able to use log(DPR) which is needed for data distribution normality.

data <- read.csv( "DATApopulations.csv", sep=";")

#  Create phylogenetic geographic and PI matrices
phyloMat <- vcv.phylo( tree2 )
phyloMat <- phyloMat / max( phyloMat )
distanceMatrix <- dist.mat( data$Latitude, data$Longitude, data$species ) 
diag( distanceMatrix ) <- diag(distanceMatrix) + 0.01
distanceMatrix <- distanceMatrix / 1.01

idxMat <- apply( phyloMat, 1:2, function(i) as.numeric( i > 0) )


I0 <- diag(1, dim(data)[1] )
rownames(I0) <- colnames(I0) <- data$species 
I <- diag(1 / data$N_nests )

I <- I / max(I)
rownames(I) <- colnames(I) <- data$species 


# Form a matrix representing species identity
m <- as.matrix( model.matrix( ~ species-1, data = data) )
S <- crossprod(t(m), t(m) )
rownames(S) <- colnames(S) <- data$species 

# Create a latitude variable

data$NS <- data$Latitude > 0



#---- Run one of the key models: -------

model_26 <- lmekin( log(DPR) ~ (1|species) + log( N_nests) + mean_year + NS + abs( Latitude ), varlist = list( I, phyloMat, distanceMatrix), data = data )
model_26



# Now iterate across all trees


form  <- as.formula( "log(DPR) ~ (1|species) + log( N_nests) + mean_year + NS + abs( Latitude )" )


# - this creates a list of models, run once for each of the phylogenies 
models <- lapply( phyloMats, function( p ) lmekin( form, varlist = list(I, p, distanceMatrix), data = data) )


extractFixedCoeffs <- sapply( models, function(m) m$coefficients$fixed, simplify = TRUE)
#--- The variance among trees is very low indeed:

layout( matrix( c(1,2,3,4,5,6),2))
apply( extractFixedCoeffs, 1, hist)
apply( extractFixedCoeffs, 1, mean)
apply( extractFixedCoeffs, 1, var)
apply( extractFixedCoeffs, 1, function(x) abs( sqrt(var(x)) / mean(x)) ) # Coefficient of variation



