
### -----------------------------------------------
### - Fig. S1 --- Geographical distribution of the analysed data on nest predation of shorebirds - one map
### -----------------------------------------------


rm( list = ls() )

library(dplyr) # for "glimpse"
library(sp)
library(gstat)
library(ggplot2)
library( scales ) # for "comma"
library( magrittr )
library( kriging )
library( lattice )
library( alphahull)
library( blighty )
library( raster)
library( spatstat )
library( maptools )
library( tmap )
library( mgcv )
library( rgeos )
library( Cairo )
library( rworldmap )
library( cleangeo )
library( maps )
library(RColorBrewer)
library(lodplot)



# This solution for re-centering maps taken from:
# https://stackoverflow.com/questions/5353184/fixing-maps-library-data-for-pacific-centred-0-360-longitude-display

plot.map<- function(database,center,...){
  Obj <- map(database,...,plot=F)
  coord <- cbind(Obj[[1]],Obj[[2]])
  
  # split up the coordinates
  id <- rle(!is.na(coord[,1]))
  id <- matrix(c(1,cumsum(id$lengths)),ncol=2,byrow=T)
  polygons <- apply(id,1,function(i){coord[i[1]:i[2],]})
  
  # split up polygons that differ too much
  polygons <- lapply(polygons,function(x){
    x[,1] <- x[,1] + center
    x[,1] <- ifelse(x[,1]>180,x[,1]-360,x[,1])
    if(sum(diff(x[,1])>300,na.rm=T) >0){
      id <- x[,1] < 0
      x <- rbind(x[id,],c(NA,NA),x[!id,])
    }
    x
  })
  # reconstruct the object
  polygons <- do.call(rbind,polygons)
  Obj[[1]] <- polygons[,1]
  Obj[[2]] <- polygons[,2]
  
  return( map(Obj, ...) )
  
}



get.coord <- function(lon, center, ...) {
  
  newlon <- lapply(lon,function(x){
    x <- x + center
    x <- ifelse(x > 180, x -360, x)
    x
  })
  
  return( newlon )
  
}



mypalette <- brewer.pal(3, "Spectral")
mypalette <- c("mediumaquamarine","tan1","mediumpurple1"  )


sPDF <- getMap()
sPDF <- clgeo_Clean(sPDF)  ## Needed to fix up some non-closed polygons 

continents <-  levels(sPDF$continent)
#idx <- which(continents == "Antarctica")
#continents <- continents[-idx]



cont <-    sapply(continents,
                  FUN = function(i) {
                    ## Merge polygons within a continent
                    poly <- gUnionCascaded(subset(sPDF, continent==i))
                    ## Give each polygon a unique ID
                    poly <- spChFIDs(poly, i)
                    ## Make SPDF from SpatialPolygons object
                    SpatialPolygonsDataFrame(poly,
                                             data.frame(continent=i, row.names=i))
                  },
                  USE.NAMES=TRUE)

## Bind the 6 continent-level SPDFs into a single SPDF
cont <- Reduce(spRbind, cont)
data( gridExData)
np <- SpatialPoints( coordinates( gridExData)  )
ngrid <- points2grid( np )

# Load the data 

figS1data <- read.csv("Fig.S1.csv", sep=";")

figS1data$color <- as.character( recode(figS1data$Clade,
                                        "Charadrii" = "darkgoldenrod", "Scolopaci+" = "darkorchid1"  ) )
figS1data$size <- as.numeric( recode(figS1data$Populations, "one" = 0.5, "two-three" = 0.8, "four+" = 1.2) )



# NB - have to recenter the map to properly plot points at the edge

plot.map("world",resolution = 0, center = 5, col = "white", bg = "lightcyan2", ylim = c(-90,90), fill = TRUE)
idx <- which(figS1data$color != "Both")
points( get.coord( figS1data$Longitude[idx], 5), figS1data$Latitude[idx], col =figS1data$color[idx], pch = 19, cex =figS1data$size[idx]   )

idx <- which(figS1data$color == "Both")
points( get.coord( figS1data$Longitude[idx], 5), figS1data$Latitude[idx],  col =  "darkgoldenrod", pch = 19,cex =figS1data$size[idx]  )
points( get.coord( figS1data$Longitude[idx], 5), figS1data$Latitude[idx],  col =  "darkorchid1", cex =figS1data$size[idx] )




cairo_pdf("FigS1.pdf")

plot.map("world", resolution = 0, center = 5, col = "white", bg = "lightcyan2", ylim = c(-90,90), fill = TRUE)
idx <- which(figS1data$color != "Both")
points( get.coord( figS1data$Longitude[idx], 5), figS1data$Latitude[idx], col =figS1data$color[idx], pch = 19, cex =figS1data$size[idx]   )

idx <- which(figS1data$color == "Both")
points( get.coord( figS1data$Longitude[idx], 5), figS1data$Latitude[idx],  col =  "darkgoldenrod", pch = 19,cex =figS1data$size[idx]  )
points( get.coord( figS1data$Longitude[idx], 5), figS1data$Latitude[idx],  col =  "darkorchid1", cex =figS1data$size[idx] )
points( get.coord( figS1data$Longitude[idx], 5), figS1data$Latitude[idx],  col =  "darkorchid1", cex =figS1data$size[idx]*0.8 )

dev.off()





### -----------------------------------------------
### - Fig. S2 --- Temporal changes in nest predation of shorebirds in 20 years intervals - four graphs
### -----------------------------------------------



data <- read.csv("DATApopulations_intervals.csv", h = T, sep=";")
summary(data)

library(ggplot2)

###### - this approach is adjusted from: http://www.cookbook-r.com/Graphs/Plotting_means_and_error_bars_(ggplot2)/#Helper%20functions 
## Gives count, mean, standard deviation, standard error of the mean, and confidence interval (default 95%).
##   data: a data frame.
##   measurevar: the name of a column that contains the variable to be summariezed
##   groupvars: a vector containing names of columns that contain grouping variables
##   na.rm: a boolean that indicates whether to ignore NA's
##   conf.interval: the percent range of the confidence interval (default is 95%)
summarySE <- function(data=NULL, measurevar, groupvars=NULL, na.rm=FALSE,
                      conf.interval=.95, .drop=TRUE) {
  library(plyr)
  
  # New version of length which can handle NA's: if na.rm==T, don't count them
  length2 <- function (x, na.rm=FALSE) {
    if (na.rm) sum(!is.na(x))
    else       length(x)
  }
  
  # This does the summary. For each group's data frame, return a vector with
  # N, mean, and sd
  datac <- ddply(data, groupvars, .drop=.drop,
                 .fun = function(xx, col) {
                   c(N    = length2(xx[[col]], na.rm=na.rm),
                     mean = mean   (xx[[col]], na.rm=na.rm),
                     sd   = sd     (xx[[col]], na.rm=na.rm)
                   )
                 },
                 measurevar
  )
  
  # Rename the "mean" column    
  datac <- rename(datac, c("mean" = measurevar))
  
  datac$se <- datac$sd / sqrt(datac$N)  # Calculate standard error of the mean
  
  # Confidence interval multiplier for standard error
  # Calculate t-statistic for confidence interval: 
  # e.g., if conf.interval is .95, use .975 (above/below), and use df=N-1
  ciMult <- qt(conf.interval/2 + .5, datac$N-1)
  datac$ci <- datac$se * ciMult
  
  return(datac)
}



###
### Fig. S2A - DAILY nest predation rate - temporal trends for different latitudinal areas
###


tg <- data
head(tg)

tgc <- summarySE(tg, measurevar="DPR_orig", groupvars=c("Belt2","interval"))
tgc

tgc$col <- NA
tgc$col[ tgc$Belt2 == "1_South temperate" ] <- "lightseagreen"
tgc$col[ tgc$Belt2 == "2_South tropics"] <- "gray57"
tgc$col[ tgc$Belt2 == "3_North tropics"] <- "darkorange4"
tgc$col[ tgc$Belt2 == "4_North temperate"] <- "darkolivegreen4"
tgc$col[ tgc$Belt2 == "5_Arctic"] <- "deeppink"

# Standard error of the mean
ggplot(tgc, aes(x=interval, y=DPR_orig, colour = col)) + 
  geom_errorbar(aes(ymin=DPR_orig-se, ymax=DPR_orig+se), width=.1) +
  geom_line() +
  geom_point()


# The errorbars overlapped, so use position_dodge to move them horizontally
pd <- position_dodge(0.5) # move them .05 to the left and right


p <- ggplot(tgc, aes(x=interval, y=DPR_orig, color = col , label = N )) + 
  geom_errorbar(aes(ymin=DPR_orig-se, ymax=DPR_orig+se), width=.1, position=pd) +
  geom_line(position = pd) +
  geom_point(position = pd, size = 5  )  +
  geom_text(hjust = -0.2, vjust = 1.5, position = pd, size = 5) +
  theme_bw() + 
  theme(  panel.border = element_blank(), panel.grid.major = element_blank(), 
          panel.grid.minor = element_blank()) + scale_colour_manual(name = "Region",
                                                                    labels = c("lightseagreen" ="South temperate", "gray57" = "South tropics",
                                                                                                "darkorange4" = "North tropics", "darkolivegreen4" = "North temperate",
                                                                                                "deeppink"= "Arctic"), values = c("lightseagreen" = "lightseagreen",
                                                                                                                                  "gray57" = "gray57","darkorange4" = "darkorange4",
                                                                                                                                  "darkolivegreen4" = "darkolivegreen4","deeppink"="deeppink") )

p <- p +  theme( axis.text = element_text(size = 15), axis.title = element_text(size = 15),
                 axis.line = element_line( color="black", size  = 0.5 ),
                 legend.position = c(0.2,0.85) ) + 
  theme(legend.text=element_text(size=10), legend.title=element_text(size=10))+
  labs(x="Time interval",y="Daily nest predation")

p




###
### Fig. S2B - TOTAL nest predation rate - temporal trends for different latitudinal areas
###

tg <- data
head(tg)

tgc <- summarySE(tg, measurevar="TPR_perc", groupvars=c("Belt2","interval"))
tgc


tgc$col <- NA
tgc$col[ tgc$Belt2 == "1_South temperate" ] <- "lightseagreen"
tgc$col[ tgc$Belt2 == "2_South tropics"] <- "gray57"
tgc$col[ tgc$Belt2 == "3_North tropics"] <- "darkorange4"
tgc$col[ tgc$Belt2 == "4_North temperate"] <- "darkolivegreen4"
tgc$col[ tgc$Belt2 == "5_Arctic"] <- "deeppink"

# Standard error of the mean
ggplot(tgc, aes(x=interval, y=TPR_perc, colour = col)) + 
  geom_errorbar(aes(ymin=TPR_perc-se, ymax=TPR_perc+se), width=.1) +
  geom_line() +
  geom_point()



# The errorbars overlapped, so use position_dodge to move them horizontally
pd <- position_dodge(0.4) # move them .05 to the left and right


p <- ggplot(tgc, aes(x=interval, y=TPR_perc, color = col , label = N )) + 
  geom_errorbar(aes(ymin=TPR_perc-se, ymax=TPR_perc+se), width=.1, position=pd) +
  geom_line(position = pd) +
  geom_point(position = pd, size = 5  )  +
  geom_text(hjust = -0.2, vjust = 1.5, position = pd, size = 5) +
  theme_bw() + 
  theme(  panel.border = element_blank(), panel.grid.major = element_blank(), 
          panel.grid.minor = element_blank()) + scale_colour_manual(name = "Region",
                                                                    labels = c("lightseagreen" ="South temperate", "gray57" = "South tropics",
                                                                               "darkorange4" = "North tropics", "darkolivegreen4" = "North temperate",
                                                                               "deeppink"= "Arctic"), values = c("lightseagreen" = "lightseagreen",
                                                                                                                 "gray57" = "gray57","darkorange4" = "darkorange4",
                                                                                                                 "darkolivegreen4" = "darkolivegreen4","deeppink"="deeppink") )


p <- p +  theme( axis.text = element_text(size = 15), axis.title = element_text(size = 15),
                 axis.line = element_line( color="black", size  = 0.5 ),
                 legend.position = c(0.2,0.85) ) + 
  theme(legend.text=element_text(size=10), legend.title=element_text(size=10))+
  labs(x="Time interval",y="Total nest predation (%)")


p




###
### Fig. S2C - DAILY nest predation rate - temporal trends for clades
###

tg <- data
head(tg)

tgc <- summarySE(tg, measurevar="DPR_orig", groupvars=c("clade","interval"))
tgc

tgc$col <- NA
tgc$col[ tgc$clade == "Charadrii" ] <- "darkgoldenrod"
tgc$col[ tgc$clade == "Scolopaci"] <- "darkorchid1"

# Standard error of the mean
ggplot(tgc, aes(x=interval, y=DPR_orig, colour = col)) + 
  geom_errorbar(aes(ymin=DPR_orig-se, ymax=DPR_orig+se), width=.1) +
  geom_line() +
  geom_point()


# The errorbars overlapped, so use position_dodge to move them horizontally
pd <- position_dodge(0.4) # move them .05 to the left and right



p <- ggplot(tgc, aes(x=interval, y=DPR_orig, colour=clade, label = N)) + 
  geom_errorbar(aes(ymin=DPR_orig-se, ymax=DPR_orig+se), width=.1, position=pd) +
  geom_line(position=pd) +
  geom_point(position=pd, size = 5) +
  geom_text(hjust = -0.2, vjust = 1.5, position = pd, size = 5) +
  theme_bw() + 
  theme(  panel.border = element_blank(), panel.grid.major = element_blank(), 
          panel.grid.minor = element_blank()) 


p <- p + scale_colour_manual(name = "clade", labels = c("Charadrii", "Scolopaci"), values = c("darkgoldenrod","darkorchid1") )

                                        

p <- p +  theme( axis.text = element_text(size = 15), axis.title = element_text(size = 15),
                 axis.line = element_line( color="black", size  = 0.5 ),
                 legend.position = c(0.2,0.85) ) + 
  theme(legend.text=element_text(size=15), legend.title=element_text(size=15))+
  labs(x="Time interval",y="Daily nest predation")


p <- p + ylim(0, 0.06)

p




###
### Fig. S2D - TOTAL nest predation rate - temporal trends for clades
###


tg <- data
head(tg)

tgc <- summarySE(tg, measurevar="TPR_perc", groupvars=c("clade","interval"))
tgc


tgc$col <- NA
tgc$col[ tgc$clade == "Charadrii" ] <- "darkgoldenrod"
tgc$col[ tgc$clade == "Scolopaci"] <- "darkorchid1"

# Standard error of the mean
ggplot(tgc, aes(x=interval, y=DPR_orig, colour = col)) + 
  geom_errorbar(aes(ymin=TPR_perc-se, ymax=TPR_perc+se), width=.1) +
  geom_line() +
  geom_point()


# The errorbars overlapped, so use position_dodge to move them horizontally
pd <- position_dodge(0.4) # move them .05 to the left and right



p <- ggplot(tgc, aes(x=interval, y=TPR_perc, colour=clade, label = N)) + 
  geom_errorbar(aes(ymin=TPR_perc-se, ymax=TPR_perc+se), width=.1, position=pd) +
  geom_line(position=pd) +
  geom_point(position=pd, size = 5) +
  geom_text(hjust = -0.2, vjust = 1.5, position = pd, size = 5) +
  theme_bw() + 
  theme(  panel.border = element_blank(), panel.grid.major = element_blank(), 
          panel.grid.minor = element_blank()) 

p <- p + scale_colour_manual(name = "clade", labels = c("Charadrii", "Scolopaci"), values = c("darkgoldenrod","darkorchid1") )


p <- p +  theme( axis.text = element_text(size = 15), axis.title = element_text(size = 15),
                 axis.line = element_line( color="black", size  = 0.5 ),
                 legend.position = c(0.2,0.85) ) + 
  theme(legend.text=element_text(size=10), legend.title=element_text(size=10))+
  labs(x="Time interval",y="Total nest predation (%)")

p <- p + ylim(0, 80)


p






### -----------------------------------------------
### - Fig. S3 --- Latitudinal gradient in historic versus recent nest predation of shorebirds - two graphs
### -----------------------------------------------



###
### Fig. S3A - DAILY nest predation rate - latitudinal gradinets
###


tg <- data
head(tg)

tgc <- summarySE(tg, measurevar="DPR_orig", groupvars=c("period","Belt2"))
tgc

tgc$col <- NA
tgc$col[ tgc$period == "after 2000" ] <- "red"
tgc$col[ tgc$period == "before 2000"] <- "blue"

# Standard error of the mean
ggplot(tgc, aes(x=interval, y=DPR_orig, colour = col)) + 
  geom_errorbar(aes(ymin=DPR_orig-se, ymax=DPR_orig+se), width=.1) +
  geom_line() +
  geom_point()



# The errorbars overlapped, so use position_dodge to move them horizontally
pd <- position_dodge(0.4) # move them .05 to the left and right



p <- ggplot(tgc, aes(x=Belt2, y=DPR_orig, colour=period, label = N)) + 
  geom_errorbar(aes(ymin=DPR_orig-se, ymax=DPR_orig+se), width=.1, position=pd) +
  geom_line(position=pd) +
  geom_point(position=pd, size = 5) +
  geom_text(hjust = -0.2, vjust = 1.5, position = pd, size = 5) +
  theme_bw() + 
  theme(  panel.border = element_blank(), panel.grid.major = element_blank(), 
          panel.grid.minor = element_blank()) 

p <- p + scale_colour_manual(name = "period", labels = c("after 2000", "before 2000"), values = c("red","blue") )


p <- p +  theme( axis.text = element_text(size = 15), axis.title = element_text(size = 15),
                 axis.line = element_line( color="black", size  = 0.5 ),
                 legend.position = c(0.2,0.85) ) + 
  theme(legend.text=element_text(size=15), legend.title=element_text(size=15))+
  labs(x="Latitudinal area",y="Daily nest predation")

p <- p + ylim(0, 0.06)


p






###
### Fig. S3B - TOTAL nest predation rate - latitudinal gradinets
###


tg <- data
head(tg)

tgc <- summarySE(tg, measurevar="TPR_perc", groupvars=c("period","Belt2"))
tgc


tgc$col <- NA
tgc$col[ tgc$period == "after 2000" ] <- "red"
tgc$col[ tgc$period == "before 2000"] <- "blue"

# Standard error of the mean
ggplot(tgc, aes(x=interval, y=DPR_orig, colour = col)) + 
  geom_errorbar(aes(ymin=TPR_perc-se, ymax=TPR_perc+se), width=.1) +
  geom_line() +
  geom_point()


# The errorbars overlapped, so use position_dodge to move them horizontally
pd <- position_dodge(0.4) # move them .05 to the left and right



p <- ggplot(tgc, aes(x=Belt2, y=TPR_perc, colour=period, label = N)) + 
  geom_errorbar(aes(ymin=TPR_perc-se, ymax=TPR_perc+se), width=.1, position=pd) +
  geom_line(position=pd) +
  geom_point(position=pd, size = 5) +
  geom_text(hjust = -0.2, vjust = 1.5, position = pd, size = 5) +
  theme_bw() + 
  theme(  panel.border = element_blank(), panel.grid.major = element_blank(), 
          panel.grid.minor = element_blank()) 

p <- p + scale_colour_manual(name = "period", labels = c("after 2000", "before 2000"), values = c("red","blue") )


p <- p +  theme( axis.text = element_text(size = 10), axis.title = element_text(size = 15),
                 axis.line = element_line( color="black", size  = 0.5 ),
                 legend.position = c(0.2,0.85) ) + 
  theme(legend.text=element_text(size=15), legend.title=element_text(size=15))+
  labs(x="Latitudinal area",y="Total nest predation (%)")

p <- p + ylim(0, 80)

p
